@@ -1,8 +1,8 @@
 #log# Automatic Logger file. *** THIS MUST BE THE FIRST LINE ***
 #log# DO NOT CHANGE THIS LINE OR THE TWO BELOW
-#log# opts = Struct({'__allownew': True, 'logfile': 'ipython_log.py', 'pylab': 1})
+#log# opts = Struct({'__allownew': True, 'logfile': 'ipython_log.py'})
 #log# args = []
 #log# It is safe to make manual edits below here.
 #log#-----------------------------------------------------------------------
-import os
-#?os.remove
+_ip.magic("run io")
+_ip.magic("run io")
